# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Original framework from Netrender
# Original Octane script from Enrico Cerica

import bpy, os

class OctaneRenderSettings(bpy.types.IDPropertyGroup):
	pass

def addProperties():
	from bpy.props import PointerProperty, StringProperty, BoolProperty, EnumProperty, IntProperty, CollectionProperty

	bpy.types.Scene.octane_render = PointerProperty(type=OctaneRenderSettings, name="Octane Render", description="Octane Render Settings")

	default_path = os.environ.get("TEMP")
    
	if not default_path:
		if os.name == 'nt':
			default_path = "c:/tmp/"
		else:
			default_path = "/tmp/"
	elif not default_path.endswith(os.sep):
		default_path += os.sep

# Octane Render Plug-in
	OctaneRenderSettings.panel_mode = EnumProperty(
		items=(
			("MODE_EXPORT", "Export",    "Only exports to OBJ/MTL"),
			("MODE_RENDER", "Image",     "Render still image"),
			("MODE_ANIM",   "Animation", "Render animation"),
			),
		name="Panel Mode",
		description="Render/Export target",
		default="MODE_RENDER")

	OctaneRenderSettings.image_output = StringProperty(
		name="Animation Output",
		description="Output path for animation frames",
		maxlen = 200,
		default = default_path,
		subtype='FILE_PATH')

				
	OctaneRenderSettings.export_samples_per_image = IntProperty(
		attr="",
		name="Samples",
		description="Samples per image",
		min=4,
		max=64000,
		default=256)
				
	OctaneRenderSettings.export_samples_presets = EnumProperty(  
		name="Presets",
		description="Samples per image presets",
		items=(
			("0",  "Very Low (8)", ""),
			("1", "Low (32)", ""),
			("2",  "Medium (256)", ""),
			("3",  "Medium/High (512)", ""),
			("4",  "High (1024)", ""),
			("5",  "Very High (4096)", ""),
			("6",  "Too High (8192)", ""),
			("7",  "Insane (16384)", "")
			),
		default= "2")

	OctaneRenderSettings.prv_export_samples_presets = StringProperty(
		name="Previous Samples presets",
		description="Previous Samples presets",
		maxlen = 1,
		default = " ")

# Dimensions

	# Resolution
	OctaneRenderSettings.resolution_width = IntProperty(
		attr="",
		name="Width",
		description="Horizontal resolution",
		min=16,
		max=65536,
		default=1024)

	OctaneRenderSettings.resolution_height = IntProperty(
		attr="",
		name="Height",
		description="Vertical resolution",
		min=16,
		max=65536,
		default=512)

	OctaneRenderSettings.percent_size = IntProperty(
		name="",
		description="Resize",
		min=1,
		max=100,
		default=100,
		subtype='PERCENTAGE')

	# Frame Range
	OctaneRenderSettings.animation_start = IntProperty(
		attr="",
		name="Start",
		description="Start frame",
		min=1,
		max=20000,
		default=1)

	OctaneRenderSettings.animation_end = IntProperty(
		attr="",
		name="End",
		description="End frame",
		min=1,
		max=20000,
		default=250)
				
	OctaneRenderSettings.animation_step = IntProperty(attr="",
		name="Step",
		description="Step",
		min=1,
		max=100,
		default=1)

# Octane Project Settings
	OctaneRenderSettings.path = StringProperty(
		name="Project Path",
		description="Requires Absolute Path",
		maxlen = 128,
		default = "",
		subtype='DIR_PATH')

	OctaneRenderSettings.project_name = StringProperty(
		name="Project name",
		description="Octane project name",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.unit_size = EnumProperty(  
		name="Native Unit Size",
		description="Native Units",
		items=(
			("11",  "Miles", ""),
			("10", "Furlongs", ""),
			("9",   "Yards", ""),
			("8",   "Feets", ""),
			("7",   "Inches", ""),
			("6",   "Kilometers", ""),
			("5",   "Hectometers", ""),
			("4",   "Decameters", ""),
			("3",   "Meters", ""),
			("2",   "Decimeters", ""),
			("1",   "Centimeters", ""),
			("0",   "Milimeters", "")
			),
		default= "3")

# Octane Environement Settings

	OctaneRenderSettings.replace_project = BoolProperty(
		name="Overwrite project .ocs file",
		description="Will destroy material setup in Octane",
		default = False)

	OctaneRenderSettings.relink_obj = BoolProperty(
		name="Relink OBJ to existing OCS",
		description="Forece OBJ mesh file to relink into rendered OCS",
		default = False)

	# Camera Properties
	OctaneRenderSettings.export_camera = BoolProperty(
		name="Export Camera settings",
		description="Select camera and click button",
		default = True)

	OctaneRenderSettings.active_camera = StringProperty(
		name="Camera",
		description="Active Camera",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.lens_aperture = BoolProperty(
		name="Set Lens Aperture",
		description="Lens Aperture",
		default = False)

	OctaneRenderSettings.lens_aperture_value = IntProperty(
		attr="",
		name="Value",
		description="Value",
		min=-1, max=100, default=1)

	OctaneRenderSettings.lens_aperture_curve = BoolProperty(
		name="Curve",
		description="Curve - Not implemented yet",
		default = False)

	OctaneRenderSettings.focal_depth = BoolProperty(
		name="Set Focal Depth",
		description="Focal Depth",
		default = False)

	OctaneRenderSettings.focal_depth_value = IntProperty(
		attr="",
		name="Value",
		description="Value",
		min=-1, max=100, default=5)

	OctaneRenderSettings.focal_depth_curve = BoolProperty(
		name="Curve",
		description="Curve - Not implemented yet",
		default = False)

	OctaneRenderSettings.camera_motion = BoolProperty(
		name="Camera Motion",
		description="Use camera motion for animation",
		default = False)

	OctaneRenderSettings.interpolate_frame = EnumProperty(  
		name="Interpolate",
		description="Interpolate frame",
		items=(
			("0",  "Next", ""),
			("1", "Previous", "")
			),
		default= "0")

	#Daylight Environment
	OctaneRenderSettings.export_sundir = BoolProperty(
		name="Export Sun Direction",
		description="Export Sun Direction",
		default = False)

	OctaneRenderSettings.active_light_source = StringProperty(
		name="Sun Light",
		description="Set a Sun Light Source",
		maxlen = 128,
		default = "")

# Octane Export Settings

	# Context
	OctaneRenderSettings.export_sel_only = BoolProperty(
		name="Selection Only",
		description="Only export objects in visible selection. Else export whole scene.",
		default = False)

	OctaneRenderSettings.export_remove_hidden = BoolProperty(
		name="Remove Hidden",
		description="Remove hidden objects from export result",
		default = False)

	# Output Opyions
	OctaneRenderSettings.export_apply_modifiers = BoolProperty(
		name="Apply Modifiers",
		description="Use transformed mesh data from each object. May break vert order for morph targets.",
		default = True)

	OctaneRenderSettings.export_ROTX90=BoolProperty(
		name="Rotate X90",
		description="Rotate on export so Blenders UP is translated into OBJs UP",
		default = True)

	OctaneRenderSettings.export_copy_images = BoolProperty(
		name="Copy Images",
		description="Copy image files to the export directory, never overwrite.",
		default = True)

	# Export Options
	OctaneRenderSettings.export_edges = BoolProperty(
		name="Edges",
		description="Edges not connected to faces.",
		default = False)

	OctaneRenderSettings.export_tri=BoolProperty(
		name="Triangulate",
		description="Triangulate quads.",
		default = False)

	OctaneRenderSettings.export_materials = BoolProperty(
		name="Materials",
		description="Write a separate MTL file with the OBJ.",
		default = True)

	OctaneRenderSettings.export_UV=BoolProperty(
		name="UVs",
		description="Export texface UV coords.",
		default = True)

	OctaneRenderSettings.export_normals = BoolProperty(
		name="Normals",
		description="Export vertex normal data (Ignored on import).",
		default = True)

	OctaneRenderSettings.export_HQ = BoolProperty(
		name="HQ",
		description="Calculate high quality normals for rendering.",
		default = False)

	OctaneRenderSettings.export_polygroups = BoolProperty(
		name="Polygroups",
		description="Export vertex groups as OBJ groups (one group per face approximation).",
		default = False)

	OctaneRenderSettings.export_curves_as_nurbs = BoolProperty(
		name="Nurbs",
		description="Export 3D nurbs curves and polylines as OBJ curves, (bezier not supported).",
		default = False)

# Octane System settings
	OctaneRenderSettings.binary = StringProperty(
		name="Octane Binary",
		description="Requires Absolute Path",
		maxlen = 128,
		default = "",
		subtype='FILE_PATH')

	OctaneRenderSettings.GPU_selector = BoolProperty(
		name="GPU Devices to use",
		description="Custom GPU devices config",
		default = False)

	OctaneRenderSettings.GPU_use_list = StringProperty(
		name="",
		description="List of GPUs to use (ex: 0 1 2)",
		maxlen = 128,
		default = "")

	OctaneRenderSettings.resolution = BoolProperty(
		name="Override Octane default resolution",
		description="Export resolution",
		default = True)

	OctaneRenderSettings.verbose = BoolProperty(
		name="Verbose logging in console",
		description="Log Octane plug-in events in console",
		default = True)


